disruption parameters obtained from random forest regression to survey data. Eta values are lognormally distributed with mean log values provided for each owner-occupier household serial numbers

eta_values

Format

A data frame with 901 rows and 2 variables:

serial

character household id

log_eta_bar

double log(eta)

Details

DETAILS