fabric_grant finds the grant amount available from SEAI for building fabric energy efficiency upgrades. This function excludes grants for heat pumps and associated works. The fabric grant is expressed in terms of ber_old and ber_new. HLI values are calculated. the fabric grant depends on eligility for OSS and therefore on ber scores and uplift. This means that it depends also on tech_old and tech_new. A minimum fabric upgrdae grant of euro700 applies.

fabric_grant(
  ber_old,
  ber_new,
  tech_old,
  tech_new,
  heating_install_time,
  construction_year,
  region,
  house_type,
  storeys,
  floor_area = 100,
  is_fuel_allowance = FALSE,
  params,
  randomise = TRUE
)

Arguments

ber_old

old hli, double

ber_new

new hli, double

tech_old

old tech

tech_new

new tech

heating_install_time

decimal time

construction_year

year of construction, integer

region

region

house_type

seai house type (related to q1)

storeys

number of storeys 1, 2+

floor_area

m2

is_fuel_allowance

TRUE/FALSE

params

parameters

randomise

whether to assign grant elements randomly or not. Default TRUE, for testing set to FALSE

Value

list(scheme, grant)

Examples


params <- scenario_params(sD,2028)
fabric_grant(300,200,"gas","gas",2010,2003,"Dublin","detached",2,100, FALSE,params,randomise=TRUE)
#> $scheme
#> [1] "BetterEnergyHomes"
#> 
#> $grant_value
#> [1] 6950
#> 
#> $cost_estimate
#> [1] 18064.29
#> 
#> $grant_share
#> [1] 0.3847369
#> 

fabric_grant(300,150,"gas","gas",2010,2003,"Dublin","detached",2,100, FALSE,params,randomise=TRUE)
#> $scheme
#> [1] "BetterEnergyHomes"
#> 
#> $grant_value
#> [1] 10450
#> 
#> $cost_estimate
#> [1] 53745.46
#> 
#> $grant_share
#> [1] 0.194435
#> 

fabric_grant(300,100,"gas","gas",2010,2003,"Dublin","detached",2,100, FALSE,params,randomise=TRUE)
#> $scheme
#> [1] "OSS"
#> 
#> $grant_value
#> [1] 11850
#> 
#> $cost_estimate
#> [1] 102212.7
#> 
#> $grant_share
#> [1] 0.1159348
#> 

fabric_grant(300,150,"gas","gas",2010,2003,"Dublin","detached",2,100, is_fuel_allowance=TRUE,params,randomise=TRUE)
#> $scheme
#> [1] "WarmerHomes"
#> 
#> $grant_value
#> [1] 35000
#> 
#> $cost_estimate
#> [1] 42996.36
#> 
#> $grant_share
#> [1] 0.8140223
#> 

fabric_grant(300,150,"gas","gas",2010,2003,"Dublin","detached",2,100, is_fuel_allowance=FALSE,params,randomise=TRUE)
#> $scheme
#> [1] "BetterEnergyHomes"
#> 
#> $grant_value
#> [1] 10450
#> 
#> $cost_estimate
#> [1] 53745.46
#> 
#> $grant_share
#> [1] 0.194435
#> 

fabric_grant(300,280,"gas","gas",2010,2003,"Dublin","detached",2,100, is_fuel_allowance=FALSE,params,randomise=TRUE)
#> $scheme
#> [1] "None"
#> 
#> $grant_value
#> [1] 0
#> 
#> $cost_estimate
#> [1] 0
#> 
#> $grant_share
#> [1] 0
#> 

fabric_grant(175,155,"gas","gas",2010,2003,"Dublin","detached",2,100, is_fuel_allowance=TRUE,params,randomise=TRUE)
#> $scheme
#> [1] "BetterEnergyHomes"
#> 
#> $grant_value
#> [1] 7258.637
#> 
#> $cost_estimate
#> [1] 7258.637
#> 
#> $grant_share
#> [1] 1
#>