heating system age based on survey response and mean system lifetime based on a geometric failure distribution p(1-p)^t. This should be replaced by a more realistic discrete weibull distribution.

heating_system_age(q7, tech, params)

Arguments

q7

survey system age

tech

technology

params

current parameters

Examples

heating_system_age(6,"oil",scenario_params(sD,2015))
#> [1] 21