stochastic function that returns FALSE is the heating system did not fail during an nbservation period. Use in update_agents() to model failure and replacement of heating systems according to a weibull failure model

weibull_failure(t0, t1, t2, tech)

Arguments

t0

installation date

t1

start of observation period

t2

end of observation period

tech

heating technology

Value

did it fail? TRUE/FALSE

Examples

replicate(1000,weibull_failure(2010,2015,2016,"oil")) %>% table()
#> .
#> FALSE  TRUE 
#>   984    16