eta_values.Rddisruption parameters obtained from random forest regression to survey data. Eta values are lognormally distributed with mean log values provided for each owner-occupier household serial numbers
eta_valuesA data frame with 901 rows and 2 variables:
serialcharacter household id
log_eta_bardouble log(eta)
DETAILS