Finds the financially optimum household heating system replacement, including a heat pump.

"Savings" are relative to an replacing the current system with a new system with the same technology e.g. gas -> gas

If current system is a heat pump, the choice between a heat pump swap or reversion to gas. No status quo bias is included at present so the model ca have an unrealistic high number of heat pump defectors.

This function is used in *update_agents* to determine the new system choice when current heating system fails. A heat pump "disruption" penality is not included in the current version.

heat_pump_savings(
  hli,
  tech_old,
  installation_time,
  house_type,
  storeys,
  construction_year,
  region,
  floor_area,
  eta,
  params
)

Arguments

hli

current HLI

tech_old

current tech

installation_time

year of installation of old tech

house_type

seai house type

storeys

1 or 2+

construction_year

integer

region

region

floor_area

total floor area (m2)

eta

disruption parameter

params

current parameter values

Value

one row dataframe

Examples

params <- scenario_params(sD,2025)
heat_pump_savings(2.31,"electricity",2010,"detached",2,1995,"Munster",120,0.12,params)
#> # A tibble: 1 × 7
#>   tech_cost_stick tech_cost_switch eac_stick eac_switch savings grant_type
#>             <dbl>            <dbl>     <dbl>      <dbl>   <dbl> <chr>     
#> 1            1431            14986      4356       4617  0.0599 None      
#> # ℹ 1 more variable: heat_pump_grant <dbl>
params$beta. <- 1
heat_pump_savings(2,"solid_fuel",2010,"detached",2,1995,"Munster",100,0.12,params)
#> # A tibble: 1 × 7
#>   tech_cost_stick tech_cost_switch eac_stick eac_switch savings grant_type      
#>             <dbl>            <dbl>     <dbl>      <dbl>   <dbl> <chr>           
#> 1            2480            12655      1867       1896  0.0155 BetterEnergyHom…
#> # ℹ 1 more variable: heat_pump_grant <dbl>

heat_pump_savings(3.5,"oil",2010,"detached",2,1995,"Munster",120,0.12,params)
#> # A tibble: 1 × 7
#>   tech_cost_stick tech_cost_switch eac_stick eac_switch savings grant_type
#>             <dbl>            <dbl>     <dbl>      <dbl>   <dbl> <chr>     
#> 1            2989            19297      3275       4067   0.242 None      
#> # ℹ 1 more variable: heat_pump_grant <dbl>