heat_pump_upgrade_savings.RdThe percentage annual equivalent savings achieved by adopting a heat pump as part of an home energy upgrade.
heat_pump_upgrade_savings(
hli_old,
tech_old,
installation_time,
house_type,
storeys,
construction_year,
region,
floor_area,
eta,
params,
is_fuel_allowance,
include_grants
)starting hli
old tech
time of installation of old tech
seai house type
1 or 2+
house construction year
region
floor area in m2
heterogeneous disruption parameter
scenario params at current yeartime
default FALSE
TRUE or FALSE
a single row dataframe
Savings are expressed in two was (1) relative to the current system and (2) the current technology.
Savings are also expressed relative to current system with no upgrades (used in update_agents to determine whether an upgrade is undertaken)
If the relative gain is sufficient, a heat pump may be adopted.
For WarmerHomes, it is assumed that pre-2025 retrofits "stick" to current heating technology. Post-2025 the cost optimal choice is made.
params <- scenario_params(sD,2035)
heat_pump_upgrade_savings(4.31,"electricity",2000,"semi_detached",2,1990,"Munster",106,0.12,params,is_fuel_allowance=FALSE,include_grants=TRUE)
#> # A tibble: 1 × 16
#> hli_stick eac_stick upgrade_cost_stick tech_cost_stick grant_type_stick
#> <dbl> <dbl> <dbl> <dbl> <chr>
#> 1 3.06 6003 7094 1563 BetterEnergyHomes
#> # ℹ 11 more variables: upgrade_grant_stick <dbl>, heat_pump_grant_stick <dbl>,
#> # hli_switch <dbl>, eac_switch <dbl>, upgrade_cost_switch <dbl>,
#> # tech_cost_switch <dbl>, grant_type_switch <chr>,
#> # upgrade_grant_switch <dbl>, heat_pump_grant_switch <dbl>, savings <dbl>,
#> # eac_old <dbl>
heat_pump_upgrade_savings(4.31,"electricity",2000,"semi_detached",2,1990,"Munster",106,0,params,is_fuel_allowance=FALSE,include_grants=TRUE)
#> # A tibble: 1 × 16
#> hli_stick eac_stick upgrade_cost_stick tech_cost_stick grant_type_stick
#> <dbl> <dbl> <dbl> <dbl> <chr>
#> 1 2.78 5173 10171 1483 BetterEnergyHomes
#> # ℹ 11 more variables: upgrade_grant_stick <dbl>, heat_pump_grant_stick <dbl>,
#> # hli_switch <dbl>, eac_switch <dbl>, upgrade_cost_switch <dbl>,
#> # tech_cost_switch <dbl>, grant_type_switch <chr>,
#> # upgrade_grant_switch <dbl>, heat_pump_grant_switch <dbl>, savings <dbl>,
#> # eac_old <dbl>
heat_pump_upgrade_savings(1.1,"heat_pump",2000,"semi_detached",2,1990,"Munster",106,0.12,params,is_fuel_allowance=TRUE,include_grants=TRUE)
#> # A tibble: 1 × 16
#> hli_stick eac_stick upgrade_cost_stick tech_cost_stick grant_type_stick
#> <dbl> <dbl> <dbl> <dbl> <chr>
#> 1 0.404 4404 16473 6775 BetterEnergyHomes
#> # ℹ 11 more variables: upgrade_grant_stick <dbl>, heat_pump_grant_stick <dbl>,
#> # hli_switch <dbl>, eac_switch <dbl>, upgrade_cost_switch <dbl>,
#> # tech_cost_switch <dbl>, grant_type_switch <chr>,
#> # upgrade_grant_switch <dbl>, heat_pump_grant_switch <dbl>, savings <dbl>,
#> # eac_old <dbl>
heat_pump_upgrade_savings(3.5,"gas",2000,"semi_detached",2,1990,"Munster",106,0.12,params,is_fuel_allowance=FALSE,include_grants=TRUE)
#> # A tibble: 1 × 16
#> hli_stick eac_stick upgrade_cost_stick tech_cost_stick grant_type_stick
#> <dbl> <dbl> <dbl> <dbl> <chr>
#> 1 3.18 3991 2168 2411 BetterEnergyHomes
#> # ℹ 11 more variables: upgrade_grant_stick <dbl>, heat_pump_grant_stick <dbl>,
#> # hli_switch <dbl>, eac_switch <dbl>, upgrade_cost_switch <dbl>,
#> # tech_cost_switch <dbl>, grant_type_switch <chr>,
#> # upgrade_grant_switch <dbl>, heat_pump_grant_switch <dbl>, savings <dbl>,
#> # eac_old <dbl>