heating_system_capital_cost.RdThe cost of a new heating system ine euros. Includes VAT using the "two-thirds" rule.
Costs depends on installation time. This set from params$yeartime.
This functions assumed that ancilliary cost component is halved if the technology is unchanged ie. "swap" vs "new" where swap means that the existing technology is retained.
heating_system_capital_cost(
tech,
kW,
installation_type = "new",
house_type,
construction_year,
grant_type,
params,
include_vat = TRUE
)a list showing actual cost, grant and cost after grant
params <- scenario_params(sD,2026)
replicate(100,heating_system_capital_cost("heat_pump",13,installation_type="new","detached",2003,"OSS",params)$cost_after_grant) %>% table()
#> .
#> 6930 8930
#> 60 40
heating_system_capital_cost("heat_pump",18,installation_type="new","detached",2003,"BetterEnergyHomes",params)
#> $cost
#> [1] 21580
#>
#> $grant
#> [1] 6500
#>
#> $cost_after_grant
#> [1] 15080
#>
heating_system_capital_cost("heat_pump",18,installation_type="new","detached",2003,"WarmerHomes",scenario_params(sD,2026),include_vat = TRUE)
#> $cost
#> [1] 21580
#>
#> $grant
#> [1] 21580
#>
#> $cost_after_grant
#> [1] 0
#>
#
heating_system_capital_cost("heat_pump",5,installation_type="new","detached",2003,"OSS",scenario_params(sD,2026),include_vat = TRUE)
#> $cost
#> [1] 10790
#>
#> $grant
#> [1] 10500
#>
#> $cost_after_grant
#> [1] 290
#>
params$oil_boiler_ban <- 2030
params$yeartime <- 2035
heating_system_capital_cost("gas",8,installation_type="new","detached",2003,"OSS",params,include_vat = TRUE)
#> $cost
#> [1] 2696
#>
#> $grant
#> [1] 0
#>
#> $cost_after_grant
#> [1] 2696
#>
heating_system_capital_cost("heat_pump",5,installation_type="new","detached",2003,"None",params,include_vat = TRUE)
#> $cost
#> [1] 10790
#>
#> $grant
#> [1] 0
#>
#> $cost_after_grant
#> [1] 10790
#>
heating_system_capital_cost("oil",5,installation_type="new","detached",2003,"None",params,include_vat = TRUE)
#> $cost
#> [1] 1e+06
#>
#> $grant
#> [1] 0
#>
#> $cost_after_grant
#> [1] 1e+06
#>