heating_system_operating_cost.RdAnnual operational cost based on current fuel price, annual fuel consumption inferred from kWh heating_requirement, and heating system efficiency based on installation year.
heating_system_operating_cost(
hli,
tech,
installation_time,
floor_area,
params,
include_rebound = FALSE
)Also includes an annual maintenance cost.
params <- scenario_params(sD,2026)
heating_system_operating_cost(2.3, "heat_pump",2003,100,params)
#> [1] 1878.32
heating_system_operating_cost(3,"oil",2003,100,params,include_rebound=FALSE)
#> [1] 3285.852
heating_system_operating_cost(3,"oil",2003,100,params,include_rebound=TRUE)
#> [1] 2791.341