prior_install_year.Rdsamples the likely year of installation given that the system was replaced in failure_year
prior_install_year(failure_year, tech, initial_year = 2015, params)year
based on the posterior probability that heating system was installed in year T1 given that it failed in year T2 using a non-uniform prior that the system was installed in 2015 or before. This ensures that initial_agents() has heating systems installed before the initial year.
prior_install_year(2020,"gas",initial_year=2015,scenario_params(sD,2015))
#> [1] 2003