runABM.RdRuns home energy efficiency system adoption simulation on artificial society of ~792 agents.
Each run is performed on an independently generated social network with randomisation from initialise_agents() and
with a random micro_calibration run (index 1..100)
Bi-monthly
Good luck.
runABM(
sD,
Nrun = 1,
simulation_end = 2030,
resample_society = F,
n_unused_cores = 2,
use_parallel = T,
ignore_social = F,
quiet = TRUE
)scenario set-up dataframe, typically read with readr::read_xlxs(...,sheet=scenario)
integer, number runs
the final year of simulation of early termination is required
if TRUE resample hp_society_oo with replacement to capture additional variability
number of cores left unused in parallel/foreach. Recommended values 2 or 1.
if TRUE uses multiple cores. Use FALSE for diagnostic runs on a single core.
if TRUE ignore social network effects. Default is FALSE
if TRUE messaging is reduced
a three component list - simulation output, scenario setup, meta-parameters