weibull_failure.Rdstochastic function that returns FALSE is the heating system did not fail during an nbservation period. Use in update_agents() to model failure and replacement of heating systems according to a weibull failure model
weibull_failure(t0, t1, t2, tech)did it fail? TRUE/FALSE